package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$"`0`````````````"``@````!`$`64````#0``,JH```0!P`T`"``
M"0`H`!\`'@````8````T`$``-`!``#0```$@```!(`````4````$`````P``
M`50`0`%4`$`!5`````T````-````!`````%P```````!A`!``80`0`&$````
M&````!@````$````!`````$``````$````!``````,/4``##U`````4``0``
M`````0``P]0`0</4`$'#U````?0``!(L````!@`!```````"```!P`!``<``
M0`'````!`````0`````'````!`````0```%D`$`!9`!``60````@````(```
M``0````$````!````9P`0`&<`$`!G````"0````D````!`````0`````````
M````````````````````````````````!"]L:6(O;&0N<V\N,0`````````$
M````$`````%'3E4```````````(````&````$K(``?8`````````````````
M`````$)$,`````0````4`````T=.50!C/1G3!1W4JT8+)\>%\SE6C895K0``
M``$```0.`````0``!$\````!```$6@````$```1D`````0``!(8````!```$
MJ0````P`0!7`````#0!`8Z`````$`$`"P`````4`0`W\````!@!`!CP````*
M```&2@````L````0<```%@!!Q#`````5``````````,`0<1`<````0````%P
M```%`````G````8`0```<```"@````AP```1````?'```!(````><```$P``
M`"-O___^`$`50&____\````";___\`!`%$8`````````````````````````
M``````````````````````````````````````````!A````?````&\`````
M`````````#``````````*P```"P`````````*````&(````U````.@```"<`
M``!X````$`````````!#````)@````,```!"````'P````H```!W````2@``
M````````````3````!H```!<```````````````(````*@````\```!Q````
M&P```"(````E````>@```",`````````6@`````````O````/@```!X````9
M``````````L````3````3@`````````Y```````````````8````<@```#,`
M```M``````````````!G`````````#0``````````@```%8`````````7@``
M`$0```!N````00```$T```!'``````````````!U````!````#<````=````
M)````#@````_`````````!$````7``````````````!)````%@`````````N
M````"0```#$````V````3P```'L`````````````````````````````````
M````````````````````````!P````````````````````````!D````````
M`&T```!Y``````````````!9```````````````2````/````%``````````
M`````$L````<`````````$@````]````!@```'0````I````.P````4`````
M`````````"$````@`````````$8```!``````````!4````R````````````
M``!P````8`````````!8````#@```!0```!=````;````%(```!%````````
M``````!3````=@```%$```!5`````````%\`````````````````````````
M`````&D```````````````P`````````5````&,`````````6P````````!7
M`````````````````````````&$``````````0```&@``````````````&8`
M```````````````````-````90```&H`````````:P``````````````````
M````````````<P``````````````````````````````````````````````
M````````````````````````````````````````````````````!7D`0</P
M`````"$``!4```38`$'%R``````0`/_Q```$XP!`-\`````($@``#```!/0`
M0!>0````4!(```P```4!`$)$,``````3`/_Q```$'@````$`````$P#_\0``
M`!L`0&.@`````!(```X```4*`$!5)```!T`2```,```%(`!`*Y@```!X$@``
M#```!2X`0#;D````W!(```P```0Y`$'$0``````1`/_Q```%1`!`/KP```',
M$@``#```!5``0#YD````6!(```P```5K`$!`B````.`2```,```$D`!`8_``
M```$$0``#P``!7<`0</P`````!$``!4```6?`$)$,``````0`/_Q```%A`!`
M7&0```!H$@``#```!8P`0!90`````!(```P```2^`$'#\``````0```5```%
ME```````````$0``````!,P`0<7(`````!``__$```2W`$`64``````0```,
M```%HP!!Q"`````$$0``%0``!;<`0"W@````J!(```P```3>`$'6```````0
M`/_Q```%TP!!Q!`````$$0``%0``!"\`0<0P`````!$``!8```2?````````
M```1```````%YP!`2#0```SP$@``#```!,4`0<7(`````!``__$```7T`$`Z
MK````=02```,```&!@!`15````+D$@``#```!A,`0#R````!Y!(```P```.>
M`$!C@``````2````````OP!`8W``````$@``````!88`0!7``````!(```L`
M```N`$!!:````^@2```,```"X@!`8V``````$@```````>$`0&-0`````!(`
M``````.P`$!C0``````2```````#$@!`8S``````$@```````H``0&,@````
M`!(```````!N`$!C$``````2```````!\@!`8P``````$@```````_(`0&+P
M`````!(```````+G```````````1```````!/@!`8N``````$@```````RT`
M0&+0`````!(```````!6`$!BP``````2````````9P!`8K``````$@``````
M`0P`0&*@`````!(```````*5`$!BD``````2```````"8@!`8H``````$@``
M`````O8`0&)P`````!(```````'+`$!B8``````2````````7@!`8E``````
M$@```````9$`0&)``````!(```````$M`$!B,``````2```````#"P!`8B``
M````$@```````8L`0&(0`````!(```````(4`$!=@````#@2`@`,```#SP!`
M8@``````$@```````J$`0&'P`````!(```````'3`$!AX``````2```````#
M3`!`8=``````$@```````K,`0&'``````!(```````-A`$!AL``````2````
M```!@@!`8:``````$@```````Y``0&&0`````!(```````2A```````````1
M```````!V@!`88``````$@````````$`0%W(````L!(```P```"4`$!A<```
M```2```````%8@!`86``````$@```````7L`0&%0`````!(```````%B`$!A
M0``````2```````#VP!`83``````$@```````;P`0&$@`````!(```````-%
M```````````1```````!6`!`81``````$@```````E,`0&$``````!(`````
M``/]`$!@\``````2```````"(P``````````$@```````^(``````````!(`
M``````,9`$!@X``````2```````"RP!`8-``````$@```````5``0&#`````
M`!(```````-N`$!@L``````2```````!K@!`8*``````$@``````!:@`0&?@
M``!;ZA$```\```&C`$!@D``````2````````L0!`8(``````$@```````L8`
M0&!P`````!(```````(T`$!@8``````2```````"2`!`8%``````$@``````
M`UP`0&!``````!(```````"``$!@,``````2````````(0!`8"``````$@``
M`````*,`0&`0`````!(```````-G`$!@```````2```````#@`!`7_``````
M$@```````\$`0%_@`````!(```````+9`$!?T``````2```````#5`!`7\``
M````$@``````!'0`0%^P`````!(```````'J`$!?H``````2````````_P!`
M7Y``````$@```````.T`0%^``````!(```````%Q`$!?<``````2```````!
M&0!`7V``````$@```````<,`0%]0`````!(```````!"```````````@````
M````,P``````````(@```````@$``````````!(```````*H`$!?0``````2
M````````$0!`7<`````($@``#````L$`0%\P`````!(```````,G`$!?(```
M```2```````!M0!`7Q``````$@```````-8`0%\``````!(```````%I`$!>
M\``````2```````#-`!`7N``````$@````!?7VQI8F-?8W-U7VEN:70`7U]L
M:6)C7V-S=5]F:6YI`%]?;&EB8U]S=&%R=%]M86EN`%]?9VUO;E]S=&%R=%]?
M`%]*=E]296=I<W1E<D-L87-S97,`<W1R;F-M<`!R96%D;&EN:P!M96UC:'(`
M4&5R;%]'=&AR7VME>5]P='(`<'1H<F5A9%]G971S<&5C:69I8P!097)L7W-V
M7W-E='!V;@!097)L7W-V7W-E='!V`%!E<FQ?9&]U;G=I;F0`4&5R;%]S879E
M7V1E<W1R=6-T;W)?>`!097)L7TEC=7)S=&%C:VEN9F]?<'1R`%!E<FQ?26EN
M7V5V86Q?<'1R`%!E<FQ?26]P7W!T<@!097)L7VYE=U-6<'8`4&5R;%])979A
M;%]R;V]T7W!T<@!097)L7TEP87)S97)?<'1R`%!E<FQ?271O<%]E;G9?<'1R
M`&]P96YD:7(`<F5A9&1I<C8T`'-T<FQE;@!S<')I;G1F`%]?>'-T870V-`!U
M;FQI;FL`8VQO<V5D:7(`<FUD:7(`4&5R;%])<W1A=&)U9E]P='(`7U]L>'-T
M870V-`!A8V-E<W,`9V5T<&ED`&UE;6-P>0!R96%L;&]C`&UE;6UO=F4`<W1R
M<W1R`&=E='5I9`!?7W-T<F1U<`!S=')N8W!Y`%!E<FQ?<WES7VEN:70S`%!E
M<FQ?871F;W)K7W5N;&]C:P!P=&AR96%D7V%T9F]R:P!097)L7V%T9F]R:U]L
M;V-K`%!E<FQ?1V1O7W5N9'5M<%]P='(`<&5R;%]A;&QO8P!P97)L7V-O;G-T
M<G5C=`!097)L7TEP97)L7V1E<W1R=6-T7VQE=F5L7W!T<@!097)L7TEE>&ET
M7V9L86=S7W!T<@!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]P87)S90!P97)L
M7V1E<W1R=6-T`'!E<FQ?9G)E90!097)L7W-Y<U]T97)M`'!E<FQ?<G5N`&5X
M:70`4$Q?;65M;W)Y7W=R87``4&5R;%]C<F]A:U]N;V-O;G1E>'0`<W1R=&]K
M`'-T<F-M<`!?7V-T>7!E7V)?;&]C`&UK9&ER`&]P96XV-`!?7V5R<FYO7VQO
M8V%T:6]N`'-T9&5R<@!F<')I;G1F`&QS965K-C0`<F5A9`!C;&]S90!M96US
M970`4&5R;%])=&%I;G1E9%]P='(`4&5R;%]G=E]F971C:'!V`%!E<FQ?879?
M9F5T8V@`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%])8V]M<&-V7W!T<@!097)L
M7V%V7W-H:69T`%!E<FQ?;6=?<V5T`&5X96-V<`!B;V]T7T1Y;F%,;V%D97(`
M4&5R;%]N97=84P!097)L7VYE=UA37V9L86=S`&QI8G!E<FPN<V\N-2XQ,`!?
M1%E.04U)0U],24Y+24Y'`%]?4DQ$7TU!4`!?1TQ/0D%,7T]&1E-%5%]404),
M15\`;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`%]?<F5G
M:7-T97)?871F;W)K`&QI8F,N<V\N-@!?24]?<W1D:6Y?=7-E9`!?7V5N=FER
M;VX`;&EB8W)Y<'0N<V\N,0!?9G1E>'0`7V9D871A`%]E9&%T80!?7V)S<U]S
M=&%R=`!?9F)S<P!?96YD`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE
M`%]G<%]D:7-P`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?=7-E<FYA
M;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?7V1A=&%?<W1A<G0`>'-?
M:6YI=`!?7W-T87)T`%]?9VYU7VQO8V%L7V=P`&YA;65?;&]A9%]M>5]P87)?
M<&P`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`'-I>F5?;&]A9%]M>5]P
M87)?<&P`<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD
M<')O9P!P87)?:6YI=%]E;G8`1TQ)0D-?,BXS`$=,24)#7S(N,RXR`$=,24)#
M7S(N,@!'3$E"0U\R+C```````0`!``$``0````$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!`````0`!``$``0`!``$``0`#``$``0`!``$``0``````
M`0`!``,``P````,`````````````````!@`#``,````````````#``,`````
M``,``P`!`````P`#``,````"``,````#``,``0````,``P`#``,``P`#``0`
M```````````'`````P````,``0`$`````P```````@`"``,````#````````
M``8`!0`#```````$`````P````````````$````#``,````#``(````!``0`
M``2&````$````%`-:6D3````!P``!B`````0"6D9<@````4```8J````$`UI
M:1(````$```&-@```!`-:6D0`````P``!D````````$``@``!&0````0````
M``UI:1(````&```&-@```!`-:6D0`````@``!D``````/!P``B><+G`#F>`A
M)[W_X*^_`!ROO``0CX*!;``@""400``%`"`()8^9@6P`(`@E`R#X"0`@""4$
M$0`!`"`()3P<`$(GG$0PCYF`&``@""4G.1=4!!$`3P`@""4$$0`!`"`()3P<
M`$(GG$0PCYF`&``@""4G.5Z`!!$2$0`@""6/OP`<`"`()0/@``@GO0`@`^``
M(001``$`(`@E/!P`0B><1#```/@ACX2`/(^E```GI@`$)`'_^`.AZ"0GO?_@
MCX>`R(^(@7@`(`@EKZ@`$*^B`!2OO0`8CYF!,``@""4#(/@)`"`()1``__\`
M(`@E)[W_T*^S`"@\$P!"DF+%T*^_`"ROL@`DK[$`(!1``!JOL``</!(`0CP1
M`$(F4L/<)C'#X`(RB",\$`!"`!&(@XX"Q=0F,?__`%$8*Q!@``PD0@`!``(8
M@`)#&"&,>0```"`()0,@^`FN`L74C@+%U``@""4`41@K%&#_]B1"``$D`@`!
MHF+%T(^_`"R/LP`HC[(`)(^Q`""/L``<`^``"">]`#`\!`!"C(+#Y#P<`$(0
M0``')YQ$,(^9@6@`(`@E$R```P`@""4#(``()(3#Y`/@``@`(`@E`"`()0`@
M""6`@P```"`()1!@``\\!0!"C*7#Z`"`$"&`I0``)(0``1!E``<`(`@E@(,`
M```@""448/_[)(0``0/@``@`(`@E$`#_^0"`$"$#X``(`(`0(2>]_K@GH@`(
M)(,`'`!`."$GI@!(C&4````@""6L10``)$(`!!1&__LD8P`$).<!-">B`#R,
M1?_LC$,``(Q&_]0`HQ@FC$7_S`!F&"8`91@F``,H0``#'\(`91@EK$,`#"1"
M``041__S`"`()8^B``B,AP`0C(,``(R%``2,B``(C(8`#`#B."$\`EJ"-$)Y
MF0`#24```V;"``58)P$%4"0!B6`E`698)`#B."$`!4^```4H@@$E2"4`[#@A
M`6HH)0#E."&/I0`,``-8)P#%,"$!:%@D`2,H)`%E6"4`!U;"`,(P(0`'*4`!
M12@E`,LP(0#%,"&/K0`0``,H@@`#5X`!15`E``990``&9L(`!R@G`8M@)0$-
M0"$`ZE@D`*DH)`$":"$`JR@E``='@(^K`!0`!SB"`0=`)0&L."$`!F`G`.4H
M(0%B6"$`R#@D`8I@)`&'8"4!:4@A``4^P@`%64`!+$@ACZT`&`#K."4!)S@A
M``9/@``&,((!)D@E``=90`&B:"$`!S;"``5@)P&J:"$!B&`D`,LP)0`%5X``
MJ5@D``4H@@%%4"4!BR@ECZL`'`&F,"$`!V`G`,4P(0%B6"$`ZB@D`8E@)`&%
M8"4!:$`A``8NP@`&64`!#$`ACZT`(`"K*"4!!2@A``='@``'.((!!T`E``59
M0`&B:"$`!3["``9@)P&I:"$!BF`D`.LX)0`&3X``R%@D``8P@@$F2"4!BS`E
MCZL`)`&G."$`!6`G`.8X(0%B6"$`J3`D`8A@)`&&8"4!:E`A``<VP@`'64`!
M3%`A`,LP)0%&,"&/K0`H``57@``%*((!15`E``990``&9L(`!R@G`8M@)0&B
M:"$`ZE@D`*DH)`&H:"$`JR@E``='@(^K`"P`!SB"`0=`)0&L."$`!F`G`.4H
M(0%B6"$`R#@D`8I@)`&'8"4!:4@A``4^P@`%64`!+$@ACZT`,`#K."4!)S@A
M``9/@``&,((!)D@E``=90`&B:"$`!S;"``5@)P&J:"$!B&`D`,LP)0`%5X``
MJ5@D``4H@@%%4"4!BR@ECZL`-`&F,"$`!V`G`,4P(0%B6"$`ZB@D`8E@)`&%
M8"4!:$`A``8NP@`&64`!#$`ACZT`.`"K*"4!!2@A``='@``'.((!!T`E``59
M0`&B:"$`!3["``9@)P&I:"$!BF`D`.LX)0`&3X``R%@D``8P@@$F2"4!BS`E
MCZL`/`&G."$`!6`G`.8X(0%B6"$`J3`D`8A@)`&&8"4!:E`A``<VP@`'64`!
M3%`A`,LP)0%&,"&/K0!```57@``%*((!15`E``990``&9L(`!R@G`8M@)0&B
M:"$`ZE@D`*DH)`&H:"$`JR@E``='@(^K`$0`!SB"`0=`)0&L."$`!F`G`.4H
M(0%B6"$`R#@D`8I@)`&'8"4!:4@A``4^P@`%64`!+$@ACZT`2`#K."4!)S@A
M``9/@``&,((!)D@E``=90`&B:"$`!S;"``5@)P&J:"$!B&`D`,LP)0`%5X``
MJ5@D``4H@@%%4"4!BR@ECZL`3`&F,"$`!V`G`,4P(0%B6"$`ZB@D`8E@)`&%
M8"4!:$`A``8NP@`&64`!#$`A`*LH)8^K`%`!!2@A``='@``'.((!!T`E`6)8
M(0`%.4``!6["``9@)P&G:"4!BF`D`6E((0`&/X``R%@D``8P@@#F."4!+4@A
M`8LP)0$F2"&/I@!4``5H)P#"$"$!J&@D`*<P)`&F:"4`2E`A``EFP@`)64`!
M35`A``4W@(^M`%@`!2B"/`)NV31"ZZ$`Q3`E`8LH)0%%*"$!HF@A`,=0)@&H
M:"$!25`F``5FP@`%64``"4>``:I0(0`)2(*/K0!<`0E`)0&+2"4!25`A`:)H
M(0$&2"8!IV@A``IFP@`*64`!)4@F``4_@``%*((`Y3@E`:E((0&+*"4!)4@A
MCZ4`8`#H:"8`HB@A`:IH)@"F,"$`"6;"``E90``*+X``S3`A``I0@H^M`&0`
MJB@E`8M0)0#*,"$!HF@A`*=0)@&H:"$!25`F``9FP@`&64``"4>``:I0(0`)
M2(*/K0!H`0E`)0&+2"4!25`A`:)H(0$%2"8!IV@A`29()@`&/X`!J4@A``8P
M@H^M`&P`YC@E``IFP@`*64`!BS`E`:)H(0#H8"8!)D@A`:5H(0&*8"8`"B^`
M``I0@@"J*"4`"5E``:Q0(0`)-L*/K0!P`,LP)0%&,"$!HF@A`*=0)@&H:"$!
M25`F``9FP@`&64``"4>``:I0(0`)2(*/K0!T`0E`)0&+2"4!25`A`:)H(0$%
M2"8!IV@A`29()@`&/X`!J4@A``8P@H^M`'@`YC@E``IFP@`*64`!BS`E`:)H
M(0#H8"8!)D@A`:5H(0&*8"8`"B^```I0@@"J*"4`"5E``:Q0(0`)-L*/K0!\
M`,LP)0%&,"$!HF@A`*=0)@&H:"$!25`F``9FP@`&64``"4>``:I0(0`)2(*/
MK0"``0E`)0&+2"4!25`A`:)H(0$%2"8!IV@A`29()@`&/X`!J4@A``8P@H^M
M`(0`YC@E``IFP@`*64`!BS`E`:)H(0#H8"8!)D@A`:5H(0&*8"8`"B^```I0
M@@"J*"4`"5E``:Q0(0`)-L*/K0"(`,LP)0%&,"$!HF@A`*=0)@&H:"$!25`F
M``9FP@`&64``"4>``:I0(0`)2(*/K0",`0E`)0&+2"4!25`A`:)H(0$%2"8!
MIV@A`29()@`&/X`!J4@A``8P@H^M`)``YC@E``IFP@`*64`!BS`E`:)H(0#H
M8"8!)D@A`:5H(0&*8"8`"B^```I0@@"J*"4`"5E``:Q0(0`)-L*/K0"4`,LP
M)0%&,"$!HF@A`*=0)@&H:"$`!F;"``990`%)4"8`"4>```E(@@$)0"4!JE`A
M`8M()0%)4"&/J0"8`05H)@$B2"$!IF@F`2<X(0#M."$`!D^`CZT`G``&,((!
M)D@E``IFP@`*64`!BS`E`:)H(0$H8"8`YC@A`:5H(0&*8"8`"B^```I0@@"J
M*"4`!UE``:Q0(0`'-L*/K0"@`,LP)0%&,"$!HF@A`*E0)@&H:"$`!F;"``99
M0`%'4"8`!T>```<X@@$'0"4!JE`A`8LX)0%'4"&/IP"D`058)@#B$"$`!F""
M``8_@`#L."4!9C`F``IFPH^M`*@`24@A``I90#P"CQLT0KS<`8M8)0$F2"$`
MZ&`E`2M((0&B:"$`Z%@D`8I@)``*-X``"E""`,HP)0&+8"4!I2@A``E90(^M
M`*P`"5;"`*PH(0%+4"4`QV`E`*I0(0#'6"0!HF@A`8E@)``)+X``"4B"`*DH
M)0&+8"4!J$`A``I90(^M`+``"D["`0Q`(0$K2"4`IF`E`0E((0"F6"0!HF@A
M`8I@)``*1X``"E""`0I`)0&+8"4!IS@A``E90(^M`+0`"5;"`.PX(0%+4"4!
M!6`E`.I0(0$%6"0!HF@A`8E@)``)/X``"4B"`.DX)0&+8"4!IC`A``I90(^M
M`+@`"D["`,PP(0$K2"4`Z&`E`,E((0#H6"0!HF@A`8I@)``*-X``"E""`,HP
M)0&+8"4!I2@A``E90(^M`+P`"5;"`*PH(0%+4"4`QV`E`*I0(0#'6"0!HF@A
M`8E@)``)+X``"4B"`*DH)0&+8"4!J$`A``I90(^M`,``"D["`0Q`(0$K2"4`
MIF`E`0E((0"F6"0!HF@A`8I@)``*1X``"E""`0I`)0&+8"4!IS@A``E90(^M
M`,0`"5;"`.PX(0%+4"4!!6`E`.I0(0$%6"0!HF@A`8E@)``)/X``"4B"`.DX
M)0&+8"4!IC`A``I90(^M`,@`"D["`,PP(0$K2"4`Z&`E`,E((0#H6"0!HF@A
M`8I@)``*-X``"E""`,HP)0&+8"4!I2@A``E90(^M`,P`"5;"`*PH(0%+4"4`
MQV`E`*I0(0#'6"0!HF@A`8E@)``)+X``"4B"`*DH)0&+8"4!J$`A``I90(^M
M`-``"D["`0Q`(0$K2"4`IF`E`0E((0"F6"0!HF@A`8I@)``*1X``"E""`0I`
M)0&+8"4!IS@A``E90(^M`-0`"5;"`.PX(0%+4"4!!6`E`.I0(0$%6"0!HF@A
M`8E@)``)/X``"4B"`.DX)0&+8"4!IC`A``I90(^M`-@`"D["`,PP(0$K2"4`
MZ&`E`,E((0#H6"0!HF@A`8I@)``*-X``"E""`,HP)0&+8"4!I2@A``E90(^M
M`-P`"5;"`*PH(0%+4"4`QV`E`*I0(0#'6"0!HF@A`8E@)``)+X``"4B"`*DH
M)0&+8"4!J$`A``I90(^M`.``"D["`0Q`(0$K2"4`IF`E`0E((0"F6"0!HF@A
M`8I@)``*1X``"E""`0I`)0&+8"4!IS@A``E90(^M`.0`"5;"`.PX(0%+4"4!
M!6`E`.I0(0$%6"0!HF@A`8E@)``)/X``"4B"`.DX)0&+8"4!IC`A``I90(^M
M`.@`"D["`,PP(0$K2"4`Z&`E`,E((0#H6"0!HF@A`8I@)``*-X``"E""`,HP
M)0&+8"4!I2@A``E90(^M`.P`"5;"`*PH(0%+4"4`QV`E`*I0(0#'6"0!HF@A
M`8E@)``)+X``"4B"`*DH)0&+8"4!J$`A``I90(^M`/``"D["`0Q`(0$K2"4`
MIF`E`0E((0"F6"0!HF@A`8I@)``*1X``"E""`0I`)0&+8"4!IS@A``E>P@`)
M44`!:E`E`.PX(0#J."&/J@#T`05H)0%"$"$!J6@D`050)`&J:"4`!V;"``=1
M0`!&,"$`"5^```E(@@%I6"4`S3`A`8I()0#),"$\`LIBCZD`^#1"P=8!(D@A
M`6A0)@$E*"$!1U`F``9NP@`&84``!T^``*I0(0`'.(*/I0#\`2=()0&L."4!
M1U`A`*(H(0$K:"8!IF@F``IFP@"H0"$`"BE``84H)0$-0"$!!4`A``8_@(^E
M`0``!C""`.8X)0"B*"$`Z6@F`:IH)@"K6"$!;5@A``HO@(^M`00`"E""`*HH
M)0`(84``"#;"`*=0)@#,,"4!HF@A`68P(0&I:"$!2%`F``9FP@`&64``"$^`
M`:I0(0`(0(*/K0$(`2A()0&+0"4!2%`A`:)H(0$E0"8!IV@A`09`)@`&/X`!
MJ$`A``8P@H^M`0P`YC@E``IFP@`*64`!BS`E`:)H(0#I8"8!!D`A`:5H(0&*
M8"8`"B^```I0@@"J*"4`"%E``:Q0(0`(-L*/K0$0`,LP)0%&,"$!HF@A`*=0
M)@&I:"$!2%`F``9FP@`&64``"$^``:I0(0`(0(*/K0$4`2A()0&+0"4!2%`A
M`:)H(0$E0"8!IV@A`09`)@`&/X`!J$`A``8P@H^M`1@`YC@E``IFP@`*64`!
MBS`E`:)H(0#I8"8!!D`A`:5H(0&*8"8`"B^```I0@@"J*"4`"%E``:Q0(0`(
M-L*/K0$<`,LP)0%&,"$!HF@A`*=0)@&I:"$!2%`F``9FP@`&64``"$^``:I0
M(0`(0(*/K0$@`2A()0&+0"4!2%`A`:)H(0$E0"8!IV@A`09`)@`&/X`!J$`A
M``8P@H^M`20`YC@E``IFP@`*64`!BS`E`:)H(0#I8"8!!D`A`:5H(0&*8"8`
M"B^```I0@@"J*"4`"%E``:Q0(0`(-L*/K0$H`,LP)0%&,"$!HF@A`*=0)@&I
M:"$!2%`F``9FP@`&64``"$^``:I0(0`(0(*/K0$L`2A()0&+0"4!2%`A`:)H
M(0$E0"8!IV@A`09`)@`&/X`!J$`A``8P@H^M`3``YC@E``IFP@`*64`!BS`E
M`:)H(0#I8"8!!D`A`:5H(0&*8"8`"B^```I0@@"J*"4`"%E``:Q0(0`(-L*/
MK0$T`,LP)0%&,"$!HF@A`*=0)@&I:"$!2%`F``9FP@`&64``"$^``:I0(0`(
M0(*/K0$X`2A()0&+0"4!2%`A`:)H(0$E0"8!IV@A`09`)@`*9L(`"EE```8_
M@`&H0"$`!C""CZT!/`#F."4!BS`E`09`(0#I8"8!HF@A`:5H(0&*8"8`"%E`
M``HO@``(-L(`"E""`*HH)0#+,"4!K%`A`48P(8^J`4``IV@F`4)0(0&H:"8`
M!F;"``990`%)2"$`"%>```A`@@%(4"4!BT`ECZL!1`$M2"$`:Q@A`2A`(0!B
M$"$!14@F`29()@`(&4``1S@A``@6P@#I."$`0Q`E`.(0(:R"````!E^`C(D`
M!(R"``B,AP`,C(,`$``&,((`RS`E`2A`(0!&$"$`ZE`A`&4H(:R%`!"LB``$
MK((`"*R*``P#X``()[T!2#P<`$(GO?_()YQ$,*^_`#2OM@`PK[4`+*^T`"BO
MLP`DK[(`(*^Q`!ROL``8K[P`$`"`D"$4@``,`*"P(0``$"&/OP`TC[8`,(^U
M`"R/M``HC[,`)(^R`""/L0`<C[``&`/@``@GO0`XCX*`P``@""6,50```"`(
M)1*@__$``!`A@((````@""400``-``"8(20#`#T00P`*`"`()0"`F"$F<P`!
M@F(````@""400``#`"`()11#__H`(`@E`G*8(XZP````(`@E$@#_W`*@B"$D
M%``]CYF`;`(`("$"0"@A`R#X"0)@,"&/O``0%$``!0(3&"&`8@```"`()1!4
M``@`(`@E)C$`!(XP````(`@E%@#_\```$"$0`/_)`"`()0(UB",`$8B#)G,`
M`:[1```0`/_#`A,0(2>]_]BOOP`D#!`*D">E`!B/OP`D`"`()0/@``@GO0`H
M)[W_X*^P`!@\$`!"C@+$`"0#__\00P`%K[\`'(^_`!R/L``8`^``"">]`"`\
M!`!`#!`*WB2$8_000``,`"`()8!"````(`@E$$``"``@""4X0@`P``(0*ZX"
MQ`"/OP`<C[``&`/@``@GO0`@```0(1``__JN`L0`/!P`0B>]_]`GG$0PK[\`
M+*^R`"BOL0`DK[``(*^\`!``@(@ACY*`P!````HGL``8CZ(`&(Y#`````A"`
M`&(0(21"``2,0P```"`()11@__RL0__\`B`@(0P0"I`"`"@A%$#_\P`@""6/
MOP`LC[(`*(^Q`"2/L``@`^``"">]`#`\'`!")[WOT"><1#"OOQ`LK[,0**^R
M$"2OL1`@K[`0'*^\`!"/F8"()[``&#P$`$``H)`A`,"8(22$9``"`"@A`R#X
M"20&#_^/O``0&$``*211__\"$1@A@&,````@""408``B`"`()0!`B"&/F8!P
M`@`@(20%`"\#(/@)`B`P(8^\`!`00``;`"`()8^9@%0`(`@E`R#X"0``("&/
MO``0C$0``(^9@2P`(`@E`R#X"0`@""6/O``0`D`H(8^9@,P"`#`A`B`X(0,@
M^`D`0"`AC[\0+(^S$"B/LA`DC[$0((^P$!P#X``()[T0,!8@_]\`(`@ECYF`
M5``@""4#(/@)```@(8^\`!",1```CYF!+``@""4#(/@)`"`()8^\`!`"0"@A
MCYF!-`)@,"$#(/@)`$`@(8^_$"R/LQ`HC[(0)(^Q$""/L!`<`^``"">]$#`\
M'`!")[W_X"><1#"OOP`<K[P`$(^9@%0`(`@E`R#X"0``("&/O``0C$0``(^9
M@2P`(`@E`R#X"0`@""6/O``0)`7__X^9@1@`(`@E`R#X"0!`("&/O``0`"`(
M)8^9@%0`(`@E`R#X"0``("&/O``0C$0``(^9@2P`(`@E`R#X"0`@""6/O``0
M/`4`0(^9@#2/OP`<`$`@(22E+H@``#`A`R``"">]`"`\'`!")[W_X"><1#"O
MOP`<K[``&*^\`!"/F8!4`"`()0,@^`D``"`AC[P`$(Q$``"/F8$L`"`()0,@
M^`D`(`@EC[P`$``@""6/F8&(`"`()0,@^`D`0"`AC[P`$(Q"``"/F8!4C%``
M!`,@^`D``"`AC[P`$(Q$``"/F8$L`"`()0,@^`D`(`@EC[P`$``@""6/F8%8
M`"`()0,@^`D`0"`AC[P`$)!"``"/F8!4H@(`&`,@^`D``"`AC[P`$(Q$``"/
MF8$L`"`()0,@^`D`(`@EC[P`$``@""6/F8&(`"`()0,@^`D`0"`AC[P`$(Q"
M``"/F8!4C%``!`,@^`D``"`AC[P`$(Q$``"/F8$L`"`()0,@^`D`(`@EC[P`
M$``@""6/F8%4`"`()0,@^`D`0"`AC$(``(^\`!",0@`0CYF`5``"%<(``"`A
M`R#X":8"`!J/O``0C$0``(^9@2P`(`@E`R#X"0`@""6/O``0`"`()8^9@8@`
M(`@E`R#X"0!`("&/O``0C$(``(^9@%2,4``$`R#X"0``("&/O``0C$0``(^9
M@2P`(`@E`R#X"0`@""6/O``0/`4`0(^9@'0DI65P```P(0,@^`D`0"`AC[P`
M$```("&/F8!4`"`()0,@^`FN`@`<C[P`$(Q$``"/F8$L`"`()0,@^`D`(`@E
MC[P`$``@""6/F8&(`"`()0,@^`D`0"`AC[P`$(Q"``"/F8!4C%``!`,@^`D`
M`"`AC[P`$(Q$``"/F8$L`"`()0,@^`D`(`@EC[P`$``@""6/F8%@`"`()0,@
M^`D`0"`AC[P`$(Q"``"/F8!4K@(`(`,@^`D``"`AC[P`$(Q$``"/F8$L`"`(
M)0,@^`D`(`@EC[P`$``@""6/F8&(`"`()0,@^`D`0"`AC[P`$(Q"``"/F8!4
MC%``!`,@^`D``"`AC[P`$(Q$``"/F8$L`"`()0,@^`D`(`@EC[P`$``@""6/
MF8"0`"`()0,@^`D`0"`AC$(``(^\`!`00``4`"`()8^9@%0`(`@E`R#X"0``
M("&/O``0C$0``(^9@2P`(`@E`R#X"0`@""6/O``0`"`()8^9@)``(`@E`R#X
M"0!`("&,0@``C[P`$(Q"`&R/F8!4K@(`)`,@^`D``"`AC[P`$(Q$``"/F8$L
M`"`()0,@^`D`(`@EC[P`$``@""6/F8&(`"`()0,@^`D`0"`AC$(``(^\`!",
M0@`$CYF`5```("$#(/@)K$``*(^\`!",1```CYF!+``@""4#(/@)`"`()8^\
M`!``(`@ECYF!B``@""4#(/@)`$`@(8Q"``"/O``0C$(`!(^9@%0``"`A`R#X
M":Q``"R/O``0C$0``(^9@2P`(`@E`R#X"0`@""6/O``0`"`()8^9@8@`(`@E
M`R#X"0!`("&/O``0C$(``(^9@%2,4``$`R#X"0``("&/O``0C$0``(^9@2P`
M(`@E`R#X"0`@""6/O``0`"`()8^9@&0`(`@E`R#X"0!`("&,0@```"`():X"
M`#"/OP`<C[``&`/@``@GO0`@/!P`0B>]_Q@GG$0PK[\`Y*^^`."OMP#<K[8`
MV*^U`-2OM`#0K[,`S*^R`,BOL0#$K[``P*^\`!`0@``%`("0(8""````(`@E
M%$``#0`@""6/OP#DC[X`X(^W`-R/M@#8C[4`U(^T`-"/LP#,C[(`R(^Q`,2/
ML`#``^``"">]`.B/F8$$`"`()0,@^`D`(`@EC[P`$!!`_^X`0(@A/!``0#P3
M`$`\%P!`)A!D$"9S9!0F]V08)[8`&"05__\D'D``CYF`Z``@""4#(/@)`B`@
M(8^\`!`00`!#`"`()9!#`!.2!````"`()1!D`$HD1P`3DF(````@""408@!-
M`"`()8^9@-@"0"`A`R#X":^G`+B/O``0CZ<`N(^9@-@`X"`A`R#X"0!`H"&/
MO``0`H(0(8^9@*0`(`@E`R#X"21$``*/O``0CZ<`N(^9@8P`0"`A`N`H(0)`
M,"$#(/@)`$"@(8^\`!`D!``#CYF!7`*`*"$#(/@)`L`P(8^\`!`050`&`"`(
M)8^B`#``(`@E,$+P`!!>`#,`(`@ECYF`U``@""4#(/@)`H`@(8^\`!``(`@E
MCYF!'``@""4#(/@)`H`@(8^\`!``(`@ECYF`Z``@""4#(/@)`B`@(8^\`!`4
M0/^_`"`()8^9@+@`(`@E`R#X"0(@("&/O``0`"`()8^9@)@`(`@E`R#X"0)`
M("$0`/^0`"`()9#D``&2`@`!`"`()1""_Z<`(`@E$`#_L0`@""60XP`!DF(`
M`0`@""448O^P`"`()9#C``*28@`"`"`()1!B_YL`(`@E$`#_J0`@""4,$`S#
M`H`@(8^\`!`0`/_0`"`()3P<`$(GO?_@)YQ$,*^_`!ROL``8K[P`$(^9@%0`
M@(`A`R#X"0``("&/O``0C$0``(^9@2P`(`@E`R#X"0`@""6/O``0`"`()8^9
M@(P`(`@E`R#X"0!`("&/O``0`$`P(8^9@10D!``#`R#X"0(`*"&/O``0$$``
M!@`@""6/OP`<```0(8^P`!@#X``()[T`((^9@%0`(`@E`R#X"0``("&/O``0
MC$0``(^9@2P`(`@E`R#X"0`@""6/O``0`"`()8^9@(P`(`@E`R#X"0!`("&,
M0P`8)`)``#!C\`"/O``0$&(`%P`@""6/F8!4`"`()0,@^`D``"`AC[P`$(Q$
M``"/F8$L`"`()0,@^`D`(`@EC[P`$``@""6/F8",`"`()0,@^`D`0"`AC$,`
M&#0"H``P8_``C[P`$!1B_]``(`@ECYF!#`(`("$#(/@))`4``H^_`!PL0@`!
MC[``&`/@``@GO0`@/!P`0B>]W]`GG$0PK[\@+*^R("BOL2`DK[`@(*^\`!"/
MF8&$`"`()0,@^`DGL``8C[P`$#P%`$"/F8&,/`<`0"2E9"``0#`A).=D+`,@
M^`D"`"`AC[P`$`1!``DGLA`<``"`(8^_("P"`!`AC[(@*(^Q("2/L"`@`^``
M"">](#"/F8"(`@`@(0)`*"$#(/@))`80`(^\`!`$0/_Q`$"((8^9@*0`(`@E
M`R#X"21$``&/O``0$$#_ZP!`@"&/F8#@`B`P(0)`*"$`0"`A`R#X"0(1B"$0
M`/_CHB````@0#;D`(`@E/!P`0B>]_\`GG$0PK[\`/*^V`#BOM0`TK[0`,*^S
M`"ROL@`HK[$`)*^P`""OO``0@*(``"0#`#T`H(`A$$,`)`"`D"&/F8#8`"`(
M)0,@^`D"`"`A`D`@(2>E`!@,$`J0`$"8(8^\`!`00``D`$"((8^9@-@`(`@E
M`R#X"0!`("$`4Q`KC[P`$!1``(T`(`@E@@(``"80``&B(@``%$#__"8Q``$`
M`!`AC[\`/(^V`#B/M0`TC[0`,(^S`"R/L@`HC[$`)(^P`"`#X``()[T`0(^9
M@-@DL``!`R#X"0(`("$"0"`A)Z4`&`P0"I``0)@AC[P`$!1`_]X`0(@ACY2`
MP``@""6.A````"`()8R"````(`@E$$``;@"`$"$``(@A)$(`!(Q#````(`@E
M%&#__"8Q``$F)0`"``4H@#P"`$*,0\7@`"`()1!@``LD`P`!CYF!9``@""4#
M(/@)`"`()8^\`!``0*@A%$``$ZZ"```0`/_-)`+__X^9@*2L0\7@`R#X"0"@
M("&/O``0$$#_^`!`J"&/F8"$`!&P@(Z%````0"`A`R#X"0+`,"&/O``0$```
M`JZ5````$;"`)B(``0`"$(`"HJ@AKJ```*^Q`!B"0@```"`()1!```X``!@A
M)`,`/1!#`#T"0!`A$````R0$`#T09``'`%(8(R1"``&`0P```"`()11@__H`
M(`@E`%(8(X^9@*2.@@``)F0``@"#("$#(/@)`%:P(8^\`!`00/_/KL(``(^"
M@,``(`@EC$,``(^B`!@`(`@E``(0@`!B$"&,0P``@D(````@""400``-H&(`
M`"0$`#T01``+)`(`/1````,F4@`!$$0`!R0"`#V"0@``)&,``:!B```40/_Z
M)E(``20"`#V@8@``)&,``8("```F$``!H&(``!1`__PD8P`!$`#_>P``$"&/
MM@`8CY2`P!``_\$`%K"`)`4`"!``_YD``(@A$`#_S0``&"$\'`!")[W_H"><
M1#"OOP!<K[X`6*^W`%2OM@!0K[4`3*^T`$BOLP!$K[(`0*^Q`#ROL``XK[P`
M&#P"`$*,5,/L/`(`0"1"9$BOH@`H/`(`0"1"9%"OH@`L/`(`0"1"9%@\$0!`
M/!``0*^B`#`\`@!`)C%D,"809$`D0F5P/!4`0*^B`#0`@)@AK[$`(*^P`"0F
MM61L$```#">R`"@#(/@)`"`()8^\`!@00``F`"`()8("````(`@E$$``%@(`
MB"&.4```)E(`!`P0"MX"("`AC[P`&`)@*"&/F8"H`$"X(1!```4`0"`A@$(`
M```@""440/_J`"`()0(@("$,$`WR`F`H(8("````(`@E%$#_[`(`B"&/OP!<
MC[X`6(^W`%2/M@!0C[4`3(^T`$B/LP!$C[(`0(^Q`#R/L``X`^``"">]`&"/
MF8#8`"`()0,@^`D"8"`AC[P`&`*`("&/F8#8`"`()0,@^`D`0/`AC[P`&`+@
M("&/F8#8`"`()0,@^`D`0+`AC[P`&`/6L"&/F8"D)L0``0,@^`D`@B`AC[P`
M&`!`L"&/F8&,`$`@(0*@*"$"8#`A`H`X(0,@^`FOMP`0`B`@(0P0#?("P"@A
M$`#_N``@""4\'`!")[W_J"><1#"OOP!4K[,`4*^R`$ROL0!(K[``1*^\`!`\
M`P!`)&-GD">B`!@D9``@C&@``(QG``2,9@`(C&4`#"1C`!"L2```K$<`!*Q&
M``BL10`,%&3_]B1"`!"48P``/`0`0*1#```,$`L$)(1D=#P$`$`,$`L$)(1D
M@#P$`$`,$`L$)(1DB#P$`$`DA&24#!`+!#P0`$`,$`L$)@1DG#P$`$`DA&2L
M#!`+!#P2`$`F1&2X#!`+!#P1`$`F)&/T#!`+!#P3`$`,$`L$)F1DQ#P$`$`,
M$`L$)(1DT#P$`$`,$`L$)(1DW#P$`$`,$`L$)(1D[#P$`$`,$`L$)(1D^#P$
M`$`,$`K>)(1E!!!```,`0"@A#!`-\B9D9,0\!`!`#!`*WB2$91@00``%`"`(
M)3P$`$`DA&4L#!`-\@!`*"$\!`!`#!`*WB2$93@00``//`0`0"9$9+@,$`WR
M`$`H(3P%`$`F!&2<#!`-\B2E96B/OP!4C[,`4(^R`$R/L0!(C[``1`/@``@G
MO0!8#!`*WB2$94B/O``0$$``!28D8_0,$`WR`$`H(1``_^X\!0!`CYF`;#P%
M`$`DI65<)Z0`*0,@^`DD!@`*%$#_Y28D8_0,$`WR)Z4`,Q``_^(\!0!`/!P`
M0B>]_^`GG$0PK[\`'*^\`!"/F8#$`"`()0,@^`D`(`@EC[P`$``@""6/F8#0
M`"`()0,@^`D`0"`A$$```@`@""6,0@``C[\`'``@""4#X``()[T`(#P<`$(G
MO?_8)YQ$,*^_`"2OL0`@K[``'*^\`!`0@``N`("((8""````(`@E$$``*@`@
M""6/F8#8`"`()0,@^`D`(`@E)$;__P(F,"$")A`KC[P`$!!``!(\!0!"C*+#
MZ(#$``"`0P```"`()1"#``DDQO__),8``1```"TDQO__@,(````@""441``H
M`"`()23&__\")A`K%$#_^0`@""44T0`H`"`()8RDP^B`PP``@((````@""40
M8@`X`"`()8^9@$2/OP`DC[$`((^P`!P#(``()[T`*(^9@*0`(`@E`R#X"20$
M``(00``'/`,`0)!D9!`D8V00H$0``)!C``$`(`@EH$,``8^_`"2/L0`@C[``
M'`/@``@GO0`H@,(````@""400__>`"`()23&__\")A`K%$#_^0`@""40T?_:
M`"`()8RDP^@DQO__`B80*Q!```8`(`@E@,,``(""````(`@E$&+_^``@""4`
MT3`C),(``BQ"$`$00/_C/!``0H^9@5`"("@A),8``0,@^`DF!,7D$`#_W"8"
MQ>2/F8"D`"`()0,@^`DD!``"$$#_UCP#`$`D9&00D(0``9!C9!"@1``!$`#_
MT*!#```\'`!")[W_V"><1#"OOP`DK[$`(*^P`!ROO``0#!`/KP"`B"&`0P``
M`"`()1!@`"0\!`!"C(3#Z`!`@"&`A```)$(``1!D`!P`(`@E@$,````@""44
M8/_[)$(``0P0"N8`(`@EC[P`$!!```X`(`@E$B``#``@""6"(@```"`()1!`
M``@\!0!`CYF`J"2E96P#(/@)`@`@(8^\`!`2`@`*`"`()8^_`"2/L0`@C[``
M'`/@``@GO0`H$`#_Y`!`@"$0`/_F`$"`(0(@("&/OP`DC[$`((^P`!P($`S#
M)[T`*#P<`$(GO?_0)YQ$,*^_`"ROL@`HK[$`)*^P`""OO``8CYF`6*^D`#"O
MI0`TKZ8`.">D`#`GI0`T`R#X"2>F`#B/O``8`"`()8^%@7"/F8"<CX2`]`,@
M^`D`H#`AC[P`&``@""6/F8$@`"`()0,@^`D``"`A@$(``(^\`!@40``A`"`(
M)8^9@20`(`@E`R#X"0`@""4\`P!"C[P`&!!``,BL8M7DCYF`[``@""4#(/@)
M`$`@(8^\`!@`(`@ECYF`5``@""4#(/@)```@(8^\`!B,1```CYF!+``@""4#
M(/@)`"`()8^\`!@`(`@ECYF`?``@""4#(/@)`$`@(8^\`!B@0```CYF`5``@
M""4#(/@)```@(8^\`!B,1```CYF!+``@""4#(/@)`"`()8^\`!@`(`@ECYF`
M4``@""4#(/@)`$`@(8^\`!B00P``CYF`5#1C``*@0P```R#X"0``("&/O``8
MC$0``(^9@2P`(`@E`R#X"0`@""6/O``8`"`()8^9@%``(`@E`R#X"0!`("&0
M0P``C[P`&#1C``&@0P``CZ0`,``@""4DA``%1(00``2``'1&@!`A1(`0`#P"
M`$!$@!@``"`()48B``#$0F?,`"`()<1#9\@`(`@E1B`0/``@""5%`0!Z`"`(
M)8^9@'@`(`@E`R#X"0`$(("/J``T/`,`0JQBU?"-!```)`<`!#P%`$*/O``8
MCZ8`,*RGU>RL1```/`0`0"2$972L1``$CX2!$"C#``*L1``(/`0`0"2$97@4
M8``+K$0`#`!`("$D`P`!``,H@`$%*"&,IP``)&,``0!F*"JLAP`0%*#_^22$
M``0DQ@`#``88@#P0`$*/F8%TC@35Y`!#&"$\!0!`K&```"2E7,ROH``0`R#X
M"0!`."&/O``8$$``'0!`B"&/F8"PC@35Y`,@^`D`(`@E/`0`0`P0"MXDA&2L
MC[P`&!!``",\$@!"C@35Y(^9@7P`(`@E`R#X"0`@""6/O``8`"`()8^9@0``
M(`@E`R#X"0`@""6/OP`L`B`0(8^R`"B/L0`DC[``(`/@``@GO0`PCYF!1(X$
MU>0#(/@)`"`()8^\`!B.!-7DCYF`L``@""4#(/@)`$"((3P$`$`,$`K>)(1D
MK(^\`!@40/_?/!(`0HY$U>@`(`@E$(``#``@""4,$!`B`"`()8^\`!@0`/_6
M`"`()3P"`$#$0F?$`"`()<1#9\`0`/^(1B(``#P$`$`,$`K>)(1DN(^\`!@`
M0"`A$$#_R:Y"U>@0`/_M`"`()8^9@$``(`@E`R#X"20$``$\!`!`CX6`8(^9
M@(``(`@E`R#X"22$9G`\'`!")[WOL"><1#"OOQ!,K[X02*^W$$2OMA!`K[40
M/*^T$#BOLQ`TK[(0,*^Q$"ROL!`HK[P`&`"`D"$\!`!`)(1DN`P0"MX`H)@A
MC[P`&#P#`$*,<,/HCYF`J`)`("$"`"@A`R#X"0!`B"&/O``8$$``$@`@""4\
M!`!`)(1DW`P0#?("0"@AC[\03`)`$"&/OA!(C[<01(^V$$"/M1`\C[00.(^S
M$#2/LA`PC[$0+(^P$"@#X``()[T04(^9@-@`(`@E`R#X"0)`("&/O``8/`,`
M0HQTP^R/F8"4`F`@(0*`*"$#(/@)`$"H(8^\`!@00/_A`$`P(3P7`$`\%@!`
M)O=D$":U``$FUF1L)[,`(#0>@`"`P@```"`()11```(`(`@E`N`P(1(@``D`
MP"@ACYF`3*^F$"`#(/@)`B`@(8^\`!B/IA`@$$``2P`@""6/F8#8`,`@(0,@
M^`FOIA`@CZ80((($````PA@A@&7__X^\`!@4I``'`"`():!@__^`9/_^@@4`
M`"1"__\0I/_[)&/__P*B$"$H0A``$$#_M@+`*"&/F8&,`@`X(0)@("$#(/@)
MK[(`$(^\`!@`(`@ECYF`5``@""4#(/@)```@(8^\`!B,1```CYF!+``@""4#
M(/@)`"`()8^\`!@`(`@ECYF`C``@""4#(/@)`$`@(8^\`!@`0#`ACYF!7"0$
M``,#(/@)`F`H(8^\`!@40``6`"`()8^9@%0`(`@E`R#X"0``("&/O``8C$0`
M`(^9@2P`(`@E`R#X"0`@""6/O``8`"`()8^9@(P`(`@E`R#X"0!`("&,0@`8
MC[P`&#!"\``07@`*`F`@(8^9@)0``"`A`R#X"0*`*"&/O``8%$#_H0!`,"$0
M`/]Y/`0`0(^9@0P`(`@E`R#X"20%``&/O``8%$#_\3P$`$`DA&3<#!`-\@)@
M*"&/O``8`"`()8^9@$0`(`@E`R#X"0)@("$0`/]J`$"0(2>]@!`\'`!"K[]_
M[*^^?^BOMW_DK[9_X*^U?]ROM'_8K[-_U*^R?]"OL7_,K[!_R"><1#`GO?X(
MK[P`(#P"`$`D0F6$KZ(`.#P"`$`D0F00KZ(`/#P"`$`D0F4PKZ(`7#P"`$`D
M0F6,KZ(`8#P"`$`D0F2\KZ(`9#P"`$`D0F64KZ(`:#P4`$`\$0!`/!``0#P3
M`$`\$@!`/`(`0"8Q97`D0F6@)A!E?"9S92PF4F68`("P(2:$9+BOH@`LK[``
M-*^Q`$"OLP!8K[$`;*^R`"@,$`K>K[$`,!!```4`(`@E@$,````@""448`%.
M-`.!K`P0#YD`(`@EC[P`(!!``5<`0*@A@K(````@""420``6`F`@(8^9@/P`
M(`@E`R#X"0`@""4"H!@A)`4`7XQ$````$I!``)*0(99$````(`@E,(0(`!2`
M``(`(`@EH&4``"1C``&`<@```"`()19`__,`(`@E`F`@(1````<GLP!<CF0`
M```@""6`@@```"`()1!``1(F<P`$#!`*W@`@""4`0)`A$$#_]@!`("$,$`U@
M`"`()8^\`"`00/_Q`"`()8^9@$0`(`@E`R#X"0)`("&/O``@$$#_Z@!`,"$T
M"(&P`1U`(8^9@-BM!@```R#X"0#`("&/O``@`J`@(8^9@-@`(`@E`R#X"0!`
M@"&/O``@`@*`(8^9@*0F$`0$`R#X"0(`("&/O``@`@`@(8^9@*0`(`@E`R#X
M"0!`@"$`0)`A/`(`0#P#`$*/O``@)$)E;#0)@;",<\/H`3U((:^B`!"OM0`4
MCYF!C(TF```\!0!`)*5EK`)`("$#(/@)`F`X(8^\`"`"0"`ACYF!@``@""4#
M(/@))`4!P"0#__^/O``@$$,`I``@""6/F8$4)`0``P)`*"$#(/@))Z8!`"0#
M__^/O``@$$,"720"0`"/HP$8`"`()3!C\``48@"I`"`()8^9@,2/M0$@`R#X
M"0`@""6/O``@%J(`HB0"`<"/HP$8`"`()3!C`?\48@"=/`0`0`P0"MXDA&10
MC[P`(!!``.H`(`@ECYF`1([5```#(/@)`$`@(0*@("$,$!%4`$`H(8^\`"`0
M0`#@`$"H(8^9@-@`(`@E`R#X"0*@("$`0+@A*$(`!(^\`"`40``C)N3__(^9
M@$P\!0!``J0@(0,@^`DDI694C[P`(!1``!LD`@`$$N(`!@*WN"&"X__[@F(`
M```@""448@`4`"`()8[6``0`(`@E$L``$``@""6/F8#8`"`()0,@^`D"P"`A
M+$,`!(^\`"`48``()$+__(^9@$P\!0!``L(@(0,@^`DDI69<$$```@`@""4"
MH+`A#!`*Y@(`J"&/O``@%$``"3P$`$"/F8!H`L`@(0,@^`D``"@AC[P`(!1`
M`*L`0+@A/`0`0#P%`$`DA&/T#!`-\B2E96B/O``@``"P(8^9@80`(`@E`R#X
M"207__^/O``@/`4`0(^9@8ROH@`0K[$`%"2E9GP"`"`A`D`P(0,@^`D"8#@A
MC[P`(!```!<D'@`1`R#X"0`@""6/O``@C$(``(^9@8047@`9`"`()0,@^`D`
M(`@EC[P`(#P%`$"/F8&,KZ(`$*^V`!2OL0`8`@`@(22E9HP"0#`A`R#X"0)@
M."&/O``@`"`()8^9@8`"`"`A`R#X"20%`<"/O``@`"`()8^9@9`05__B)M8`
M`8^9@1P`(`@E`R#X"0)`("$FA&2X#!`-\@(`*"$,$`ZK`@`@(1```!XGO0'X
MCYF!D``@""4#(/@)`"`()8Q"```D`P`1C[P`(!!#_U4\!0!`CX.`Y([&``",
M9```CYF`K*^B`!`DI66X`R#X"0)`."$0```*``"H(8^"@.2/F8"LCL8``(Q$
M```\!0!`)*5F+`)`."$#(/@)``"H(2>]`?B/OW_L`J`0(8^^?^B/MW_DC[9_
MX(^U?]R/M'_8C[-_U(^R?]"/L7_,C[!_R`/@``@GO7_P$```!R>R`#B.4```
M`"`()8("````(`@E$$#^^292``0,$`U@`@`@(8^\`"`00/_V```P(8^9@$0`
M(`@E`R#X"0(`("&/O``@$$#_[P!`,"$0`/[L-`B!L`!]&"$`0"`A#!`.JZQB
M```T!(&LC[P`(`"=("&,@@``CYF`1``@""4#(/@)`$`@(1``_\\`0*@A`D`@
M(2>R`"P,$`K>`"`()8^\`"``(`@ECYF`1!!```8`0"`A`R#X"0`@""6/O``@
M%$#^G0!`J"&.1````"`()8""````(`@E%$#_[R92``0\%0!`$`#^K":U9J".
MU0``$`#_'P`@""6/F8%()!X``B0'_^XD!O__`$`@(0,@^`FOO@`0C[P`(">V
M`:"/F8$H`N`@(0+`*"$#(/@))`8`!I.B`:"/O``@%$``!20#`$.3H@&A`"`(
M)1!#`58D`P!!CYF!2`+@("&OH``0```X(0,@^`D``#`A/`)G131"(P&OH@"<
M/`+OS31"JXFOH@"@/`*8NC1"W/ZOH@"D/`(0,C1"5':OH@"H/`+#TC1"X?"O
MH@"L-`2!H#0"@:0GHP"<`%T0(2>H`+@`G2`AC[P`(*^@`+"OH`"TKZ``^*Q#
M``"LB```CYF!*`+@("$"P"@A`R#X"30&@`"/O``@&$``>P!`\"&/HP"P`!X0
MP`!#$"$`0Q@K%&``<@`@""6/HP"T`!XO0H^D`/@`91@AKZ(`L!2``$2OHP"T
M`L`H(2O"`$`40``W`\`P(0"@$"$T!(&@`)T@(8R#```D2@!`B$D``(A(``2(
M1P`(B$0`#)A)``.82``'F$<`"YA$``\D0@`0K&D``*QH``2L9P`(K&0`#!1*
M__(D8P`0-`B!I`$=0"&-!```-`F!K#0#@:@T"(&P),;_P`$]2"$`?1@A`1U`
M(:TB``"L90``#!`%^*T&```T"8&P`3U((8TF```T!(&L-`B!J`"=("$!'4`A
M*,,`0(^\`"",@@``C04``!!@_]0T!(&@)][_P``>$8(D0P`!``,9@``"$8``
MHR@A`\+P(S0)@:`!/4@ACYF`X(TD```#(/@)`\`P(8^\`"`0`/^IK[X`^"0)
M`$`!)!`C`%XH*A"@``(#P!@A`$`8(30"@:``71`AC$(``#0(@:B/F8#@`1U`
M(0!$("$`8#`AK0,```,@^`D"P"@A-`F!J`$]2"&/H@#XC2,``"0$`$``8A`A
MC[P`(!1$_X^OH@#X-`B!I`$=0"$"PR@AC00``*TE```,$`7X`\/P(S0)@:@!
M/4@AC[P`((TE```0`/^9*\(`0(^C`+00`/^.)&,``8^9@+0`(`@E`R#X"0+@
M("&/M@"P)`7_@``6$,(P0@`_)$0``2B#`#D#HA`AC[P`((^W`+008`!SH$4`
MN#0"@:``71`AC$(``(^9@3@D!@`X`,0P(P``*"$#(/@)`$0@(30#@:0`?1@A
MC&0````71@(`%SP"`!<R`@`6+@(`%AP"`!82`J.H`/"CIP#QHZ8`\J.W`/.C
MI0#THZ,`]:.B`/8,$`7XH[8`]X^B`*PT"(&DCZ0`I(^C`*@``DP"`1U`(8^\
M`""M"0``-`B!N``$Q@(`!'P"``1R`@`#;@(``V0"``-:`@`"2@(!'4`AHZ0`
M3Z.C`%,T!(&[-`.!IX^G`)R/I0"@K0D```!]&"$`G2`A-`B!H)!C``"0A```
M``?R`@`%O@(`!;0")ZD`<``'-@(`!_P"``7*`@`"5@(!'4`AH[X`1J.W`$BC
MM@!)K0D``*._`$6CIP!'H[D`2J.E`$NCN`!,HZ\`3:.N`$ZCK0!0HZP`4:.K
M`%*CJ@!4HZ,`5:.D`%:CH@!7HZ8`1`$@L"$GMP!%$````R>^`)B2Y@``)O<`
M`8^9@8P\!0!``L`@(22E9G0#(/@))M8``H^\`"`6WO_V-`B!H`$=0"&-"```
MCYF!C*^H`!"OL0`4HZ``F#P%`$`DI69D`F`X(0(`("$#(/@)`D`P(8^\`"`0
M`/Y4`"`()30"@:``71`AC$(``(^9@3@D!@!``,0P(P``*"$#(/@)`$0@(30#
M@:0`?1@AC&0```P0!?@`(`@E-`2!H`"=("&,A```KZ``N*R``#2L@``$K(``
M"*R```RL@``0K(``%*R``!BL@``<K(``(*R``"2L@``HK(``+!``_WBL@``P
MCYF!D``@""4#(/@)``"H(8^\`"",0@``CX.`Y([&``",9```CYF`K#P%`$"O
MH@`0)*5E]`,@^`D"0#@A$`#^2R>]`?B3I`&B`"`()12#_J@`(`@EDZ,!HP`@
M""448OZD)`(`2).C`:0`(`@E%&+^H"0"`$63HP&E`"`()11B_IPD!__&CYF!
M2"0&__\"X"`A`R#X":^^`!"/O``@`N`@(8^9@2@"P"@A`R#X"20&`"F/O``@
MK[8`$(^9@8P0`/^GK[$`%#P<`$(GO?_`)YQ$,*^_`#ROM@`XK[4`-*^T`#"O
MLP`LK[(`**^Q`"2OL``@K[P`$(^9@%0`(`@E`R#X"0``("&/O``0C$0``(^9
M@2P`(`@E`R#X"0`@""6/O``0`"`()8^9@0@`(`@E`R#X"0!`("$D`P`!/`0`
M0*!#```,$`K>)(1DG(^\`!`00``%)`,`,8!$````(`@E$(,!-@`@""4,$`\@
M`"`()8^\`!``(`@ECYF`5``@""4#(/@)```@(8^\`!",1```CYF!+``@""4#
M(/@)`"`()8^\`!`\!0!`CYF!/`!`("$DI6:H)`8``0,@^`DD!P`+C[P`$!!`
M`%0`(`@E/!,`0HYCU>R,1``,*&(``HR4`!@40`$P`"`()0``B"$D$``!$```
M#3P5`$*/F8!,C$4`#`,@^`D"0"`AC[P`$!1``#T`(`@ECF/5["80``$"`Q`J
M$$``.B8Q``&/F8!4`"`()0,@^`D``"`AC[P`$(Q$``"/F8$L`"`()0,@^`D`
M(`@EC[P`$`!`("&/F8"\`H`H(0(@,"$#(/@)```X(8^\`!`00``D`$"P(8Q"
M``".I=7PC$,`"``0((``I"`A,&,$`(R2```48/_8`"`()8^9@%0`(`@E`R#X
M"0``("&/O``0C$0``(^9@2P`(`@E`R#X"0`@""6/O``0CL4``(^9@#``0"`A
M```P(0,@^`DD!P`"C[P`$`!`*"&/F8!,`"`()0,@^`D"0"`AC[P`$!!`_\4`
M(`@ECF/5[``@""4D8O__$%$`G2AC``*/F8!4`"`()0,@^`D``"`AC[P`$(Q$
M``"/F8$L`"`()0,@^`D`(`@EC[P`$#P%`$"/F8$\`$`@(22E9K`D!@`!`R#X
M"20'``6/O``0$$``'`!`@"&/F8!4`"`()0,@^`D``"`AC[P`$(Q$``"/F8$L
M`"`()0,@^`D`(`@EC[P`$(X#``R/F8$TC&4``#P&`$``0"`A`R#X"23&9K2.
M`@`,C[P`$(Q"````(`@EC$,`"#P"`$``8A`D%$``AP`@""6/F8!4`"`()0,@
M^`D``"`AC[P`$(Q$``"/F8$L`"`()0,@^`D`(`@EC[P`$#P%`$"/F8$\`$`@
M(22E9KPD!@`!`R#X"20'``6/O``0$$``&@!`@"$\!`!`#!`*WB2$9-R/O``0
M$$``A0`@""6/F8!4```@(0,@^`FOH@`8C[P`$(Q$``"/F8$L`"`()0,@^`D`
M(`@EC[P`$(X#``R/F8$TC&4``(^F`!@#(/@)`$`@(8^\`!``(`@ECYF`5``@
M""4#(/@)```@(8^\`!",1```CYF!+``@""4#(/@)/!(`0H^\`!``(`@ECYF!
M"``@""4#(/@)`$`@(8^\`!```"`ACYF`5``@""4#(/@)H$```(^\`!",1```
MCYF!+``@""4#(/@)`"`()8^\`!``(`@ECYF`2``@""4#(/@)`$`@(3P$`$"L
M0```#!`*WB2$9+B/O``0$$``7ZY"U>B/F8&``$`@(0,@^`DD!0'MC[P`$!!`
M``4D`P`1$$,``R0#__\40P!Y/`,`0H^_`#R/M@`XC[4`-(^T`#"/LP`LC[(`
M*(^Q`"2/L``@`^``"">]`$`48/]C`"`()200``&/F8!4`"`()0,@^`D``"`A
MC[P`$(Q$``"/F8$L`"`()0,@^`DF$``!C[P`$`!`("&/F8%``"`()0,@^`D"
M@"@ACF+5[(^\`!`"`A`J%$#_[``@""40`/]+`"`()8^9@%0`(`@E`R#X"0``
M("&/O``0C$0``(^9@2P`(`@E`R#X"0`@""6/O``0C@,`#(^9@*",90```R#X
M"0!`("&/O``0$`#_:``@""6`0@`!`"`()1!`_LP`(`@E$`#^Q@`@""6/F8!4
M`"`()0,@^`D``"`AC[P`$(Q$``"/F8$L`"`()0,@^`D`(`@E/`,`0HQDU?".
M`P`,C(8``(QE```,$`LD`$`@(8^\`!`0`/]\`"`()1``_QD``(@A/!$`0HXD
MU?`,$!(-`"`():Y"U>B.`@`,C[P`$(Q"````(`@EC$,`"``@""4P8P0`$&``
M-0`@""6,0@`,CYF`W(XEU?`#(/@)`$`@(8X#``R.)-7PC&,```!`B"&,8@`(
MC[P`$#!"!`",D@``$$``$0`@""6,8@`,/`0`0(^9@(`DA&;``D`H(0!`,"$#
M(/@)`B`X(8QCU?`\!`!`CD;5Z(QE``"/F8"`)(1F\`,@^`D`0#@ACYF`5``@
M""4#(/@)```@(8^\`!",1```CYF!+``@""4#(/@)`"`()8^\`!".`P`,CYF`
M,(QE````0"`A```P(0,@^`DD!P`"C[P`$!``_]X\!`!`CYF`5``@""4#(/@)
M```@(8^\`!",1```CYF!+``@""4#(/@)`"`()8^\`!".`P`,CYF`,(QE````
M0"`A```P(0,@^`DD!P`"C[P`$!``_[D`(`@E/!P`0B>]_^`GG$0PK[\`'*^\
M`!"/F8!4`"`()0,@^`D``"`AC[P`$(Q$``"/F8$L`"`()0,@^`D`(`@EC[P`
M$#P%`$`\!P!`CX:`^(^9@%R/OP`<`$`@(22E9T`DYV=<`R``"">]`"`\'`!"
M)[W_V"><1#"OOP`DK[P`&(^9@%0`(`@E`R#X"0``("&/O``8C$0``(^9@2P`
M(`@E`R#X"0`@""4,$!<9`$`@(8^\`!@`(`@ECYF`5``@""4#(/@)```@(8^\
M`!B,1```CYF!+``@""4#(/@)`"`()8^\`!@\!P!`).=E<(^9@/`\!0!`/`8`
M0*^G`!"OH``4`$`@(22E9V@#(/@)),95)(^_`"0`(`@E`^``"">]`"@\'``"
M)YSFL`.9X"&/@H`<`"`()1!```8`(`@EC$<``(^9@4P`(`@E`R``"``@""40
M`/_[```X(0`@""4`(`@E`^``"``@""4\'``")YSF:`.9X"$GO?_(K[\`-*^U
M`#"OM``LK[,`**^R`"2OL0`@K[``'*^\`!"/F8`X`("8(0"@H"$#(/@)`,"H
M(8^\`!``(`@ECY&`((^2@"``(`@E`E&0(P`2D(,20``*``"`(8XY```F$``!
M`F`@(0*`*"$#(/@)`J`P(0(2$"L40/_X)C$`!(^_`#2/M0`PC[0`+(^S`"B/
ML@`DC[$`((^P`!P#X``()[T`.``@""4`(`@E/`(`0HQ9P]0GO?_8)`+__Z^_
M`"2OL0`@$R(`"J^P`!P\$`!")A##U"01__\#(/@))A#__(X9````(`@E%S'_
M^P`@""6/OP`DC[$`((^P`!P#X``()[T`*``@""4`(`@ECYF`$`/@>"$#(/@)
M)!@`>X^9@!`#X'@A`R#X"208`'J/F8`0`^!X(0,@^`DD&`!YCYF`$`/@>"$#
M(/@))!@`>(^9@!`#X'@A`R#X"208`'>/F8`0`^!X(0,@^`DD&`!VCYF`$`/@
M>"$#(/@))!@`=(^9@!`#X'@A`R#X"208`'"/F8`0`^!X(0,@^`DD&`!OCYF`
M$`/@>"$#(/@))!@`;H^9@!`#X'@A`R#X"208`&V/F8`0`^!X(0,@^`DD&`!L
MCYF`$`/@>"$#(/@))!@`:X^9@!`#X'@A`R#X"208`&J/F8`0`^!X(0,@^`DD
M&`!ICYF`$`/@>"$#(/@))!@`:(^9@!`#X'@A`R#X"208`&>/F8`0`^!X(0,@
M^`DD&`!FCYF`$`/@>"$#(/@))!@`98^9@!`#X'@A`R#X"208`&2/F8`0`^!X
M(0,@^`DD&`!CCYF`$`/@>"$#(/@))!@`8H^9@!`#X'@A`R#X"208`&&/F8`0
M`^!X(0,@^`DD&`!@CYF`$`/@>"$#(/@))!@`7X^9@!`#X'@A`R#X"208`%Z/
MF8`0`^!X(0,@^`DD&`!=CYF`$`/@>"$#(/@))!@`7(^9@!`#X'@A`R#X"208
M`%J/F8`0`^!X(0,@^`DD&`!9CYF`$`/@>"$#(/@))!@`6(^9@!`#X'@A`R#X
M"208`%>/F8`0`^!X(0,@^`DD&`!6CYF`$`/@>"$#(/@))!@`4X^9@!`#X'@A
M`R#X"208`%*/F8`0`^!X(0,@^`DD&`!1CYF`$`/@>"$#(/@))!@`3X^9@!`#
MX'@A`R#X"208`$Z/F8`0`^!X(0,@^`DD&`!-CYF`$`/@>"$#(/@))!@`3(^9
M@!`#X'@A`R#X"208`$N/F8`0`^!X(0,@^`DD&`!*CYF`$`/@>"$#(/@))!@`
M2(^9@!`#X'@A`R#X"208`$:/F8`0`^!X(0,@^`DD&`!%CYF`$`/@>"$#(/@)
M)!@`1(^9@!`#X'@A`R#X"208`$./F8`0`^!X(0,@^`DD&`!"CYF`$`/@>"$#
M(/@))!@`08^9@!`#X'@A`R#X"208`$"/F8`0`^!X(0,@^`DD&``_CYF`$`/@
M>"$#(/@))!@`/8^9@!`#X'@A`R#X"208`#R/F8`0`^!X(0,@^`DD&``[CYF`
M$`/@>"$#(/@))!@`.H^9@!`#X'@A`R#X"208`#F/F8`0`^!X(0,@^`DD&``X
MCYF`$`/@>"$#(/@))!@`-X^9@!`#X'@A`R#X"208`#:/F8`0`^!X(0,@^`DD
M&``UCYF`$`/@>"$#(/@))!@`-(^9@!`#X'@A`R#X"208`#./F8`0`^!X(0,@
M^`DD&``RCYF`$`/@>"$#(/@))!@`,8^9@!`#X'@A`R#X"208`#"/F8`0`^!X
M(0,@^`DD&``NCYF`$`/@>"$#(/@))!@`+8^9@!`#X'@A`R#X"208`"R/F8`0
M`^!X(0,@^`DD&``KCYF`$`/@>"$#(/@))!@`*H^9@!`#X'@A`R#X"208`"F/
MF8`0`^!X(0,@^`DD&``HCYF`$`/@>"$#(/@))!@`)X^9@!`#X'@A`R#X"208
M`"2/F8`0`^!X(0,@^`DD&``C`````````````````````#P<``(GG."0`YG@
M(2>]_^"OOP`<K[P`$`01``$`(`@E/!P`0B><1#"/F8`8`"`()2<Y%K`$$>RV
M`"`()8^_`!P`(`@E`^``"">]`"````````(``5!!4E]#3$5!3@```"]P<F]C
M+W-E;&8O97AE```N````+BX``"5S+R5S````+W!R;V,O)6DO)7,`97AE`$Q$
M7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)
M0E)!4EE?4$%42````"5S)7,E<P``4$523#5,24(`````4$523$Q)0@!015),
M-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!0
M05)?5$5-4`````!005)?1$5"54<```!005)?0T%#2$4```!005)?4%)/1TY!
M344`````4$%27T%21T,`````4$%27T%21U9?,```4$%27T=,3T)!3%]$14)5
M1P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!3CT``#$```!P
M87(M`````"UE```M+0``0SI<5$5-4``O=&UP`````%1%35!$25(`5$U0`%53
M15(`````55-%4DY!344`````)7,E<R5S)7,`````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M)7,Z('-T870@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E"@``<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E,#)X````
M`"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````%-94U1%30``
M05)'5@`````8````<&5R;``````P````)7,Z(&5X96-U=&EO;B!O9B`E<R!F
M86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@=&5M<&]R87)Y('-U8F1I<F5C=&]R>2`E<R!F86EL960@+2!A8F]R
M=&EN9R!W:71H("5I+@H```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M<&5R;'AS:2YC````26YT97)N86QS.CI005(Z.D)/3U0`````+P```#H`````
M`````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@````````
M`````````````$'P````````0<____^```!P87(N<&P`````````````(R$O
M=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE
M('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@
M;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*
M(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H)'!A<E]T96UP+"`D<')O
M9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@
M;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@
M("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A=7-E<R!A
M(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R>6EN9R!T
M;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN
M:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C
M('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W
M('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE
M8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG
M<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R
M92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@("`@("`C
M($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@<&%R
M96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F(&-L96%N
M:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI4
M96UP*`H@("`@("`@("`@("!414U03$%412`]/B`G=&UP6%A86%@G+`H@("`@
M("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I
M<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@
M(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@('!R:6YT("1T;7`@
M(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R
M;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=
M.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*
M(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@
M("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@
M,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y<W1E;2@D
M8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C
M97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@+B`D=&UP
M+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@
M)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@
M($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[
M4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*
M96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D
M14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME
M9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@
M("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE
M)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?
M<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R
M86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D
M871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M]
M.PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S
M96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA
M<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@
M7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U
M;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ
M,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ
M,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L
M(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]
M?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM[
M"B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)
M3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D
M9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I
M;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L
M;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@
M("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0[
M"B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*
M("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP
M;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE
M;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF
M("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@
M("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@
M8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE
M;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>
M+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@
M("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@
M("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N
M86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<
M;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE
M(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@
M("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T
M.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I
M<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B
M=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@
M("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T[
M"B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@
M("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@
M*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`]
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@
M("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q
M=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D
M;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES
M='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N
M.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE
M+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D
M969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@
M("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA
M;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@
M("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG
M+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*
M("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@
M("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@
M("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@
M;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*
M"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I
M;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D
M(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R
M960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@
M("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y
M.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E
M='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@
M24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@
M("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L
M:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?
M1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@
M("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A
M8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC
M/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@
M("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z
M"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M
M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"@ID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*"B1Q=6EE="`](#`@=6YL
M97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT
M<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I
M;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P
M=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@
M("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R
M"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P
M87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("`C(&EF('1H
M92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M+7!A<BUO<'1I;VYS("TM
M<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@(",@=7-E('1H92!A<'`@
M=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS=&5A9"!O9B!A;GET:&EN
M9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB=70@<W1I;&P@<V5T('5P
M('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N9"!`24Y#*0H@("`@:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*("`@("`@("!S
M:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N;W)M86P@<&%R;"!B96AA
M=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,["B`@("`@("`@=VAI;&4@
M*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@("`@("!I9B`H)#$@
M97$@)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H($!A9&1?=&]?:6YC+"`D
M,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TTG
M*2!["B`@("`@("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@
M("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("`@
M("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=S:71E
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T(G
M*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@
M("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@("`@("!O<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@
M)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M5"<I('L*("`@("`@("`@("`@("`@("1C86-H95]N86UE(#T@)#(["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@
M("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@
M("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@("`@
M("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I
M<W0["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!U;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@
M<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@
M>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W
M9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@
M("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ
M6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M
M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E
M;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R
M)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@
M("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@
M(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@
M)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M971A(#U^
M(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP
M=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@
M("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L
M("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I
M.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S
M(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H
M*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@
M("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@
M("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*
M("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U
M;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C
M86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D520D%424U](&%N9"`D
M;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F
M;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@
M)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A
M;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@
M/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@
M)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D
M;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N
M("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@
M("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@
M("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@
M;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER
M92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R97%U:7)E
M7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@
M("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P
M('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@
M("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@
M("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@
M("`@("!]($!)3D,["@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E
M9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES
M=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U
M=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@
M=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@
M4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S
M=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL960N
M("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N
M*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH[
M"B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@
M("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@
M("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y
M<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@
M("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@
M("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]
M*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@
M("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@
M("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD[
M"B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>
M0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@
M)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE
M(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@
M:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O
M.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@
M<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F
M:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*
M"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F
M*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@
M("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)
M3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@
M("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@
M("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC:R!U<"!A=71O+RH@9G)O
M;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@)&-O;G1E;G0@/7X@<R]G
M;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y.R\*("`@("`@("`@
M("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H(EA33&]A9&5R+G!M(BD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A
M<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*
M("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE
M*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@
M("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@("`@("`@
M("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*
M("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@
M86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA
M;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@
M)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T
M>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^
M;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T[
M"@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!
M(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L
M('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("!I9B`H
M)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N
M,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I
M9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@
M("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X
M+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]
M("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D
M8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE
M*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M/G!R:6YT
M*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^
M=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y0
M05(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O
M=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D
M<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U
M;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H
M*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN
M=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@("`@
M(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-
M4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@
M<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@
M("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@
M)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B
M.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.
M5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B
M)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@
M("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@
M("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@
M("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@
M("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@
M("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@
M("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@
M("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@
M("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@
M("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q
M.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T
M9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@
M("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC
M;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B
M('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^
M97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@
M("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]
M?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G
M92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@
M("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*
M("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I
M;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@
M(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H
M.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I
M97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L
M;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7
M:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D
M97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*
M("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R
M97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q
M=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@
M<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U
M:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R
M97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U
M:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP
M.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@
M("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PH@("`@<F5Q=6ER92!A='1R:6)U=&5S.PH@("`@979A;"![
M(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@
M("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["B`@("!E=F%L('L@
M<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0H*
M(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R
M+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E
M='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M
M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$[
M"B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@
M*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D
M<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U
M<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO
M="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G
M971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E
M<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@
M96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M
M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@
M?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG
M>U]D96QI;7UP87(M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@
M)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@
M;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E
M96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D
M8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*
M("`@("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@
M("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D
M8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H
M,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@
M("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z
M.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O
M<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@
M("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S
M:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@
M("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B
M(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P
M96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C
M;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M
M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D[
M"B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!
M4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!
M4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P
M-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@
M:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`
M7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@
M(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE
M.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@
M(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@
M*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I
M;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R
M;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!
M4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N
M86UE('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@
M)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G
M;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R
M(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@
M("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@
M("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I
M9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@
M("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L
M:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@
M("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG
M>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@
M("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]
M"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B
M+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@
M+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@
M("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I
M9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!]
M(&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@
M("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!
M0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!4
M14U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@
M/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%
M3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6
M>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%
M04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL
M(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!
M3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@
M?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@
M*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]
M"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U
M8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@
M("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA
M:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN
M.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R
M.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N
M)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE
M(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O
M("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@
M/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D
M.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,3(*"E]?14Y$7U\*````````````
M``#_____`````/____\```````````!`9X``0&>$````````````````````
M`/____\``````````````````%OI`````````````````$!GT```````````
M````````````````````````````````@`````!`````0<7$`$'#U```````
M``````````!`8X``0&-P`$`5P`!`06@`0&-@`$!C4`!`8T``0&,P`$!C(`!`
M8Q``0&,``$!B\```````0&+@`$!BT`!`8L``0&*P`$!BH`!`8I``0&*``$!B
M<`!`8F``0&)0`$!B0`!`8C``0&(@`$!B$`!`78``0&(``$!A\`!`8>``0&'0
M`$!AP`!`8;``0&&@`$!AD```````0&&``$!=R`!`87``0&%@`$!A4`!`84``
M0&$P`$!A(```````0&$0`$!A``!`8/````````````!`8.``0&#0`$!@P`!`
M8+``0&"@`$!GX`!`8)``0&"``$!@<`!`8&``0&!0`$!@0`!`8#``0&`@`$!@
M$`!`8```0%_P`$!?X`!`7]``0%_``$!?L`!`7Z``0%^0`$!?@`!`7W``0%]@
M`$!?4`````````````````!`7T``0%W``$!?,`!`7R``0%\0`$!?``!`7O``
M0%[@``````!`%Y```````````````````````````````!T````?`$`7X```
M``````````````````````%(````'0```!\`0"I`@'\``/____P`````````
M`````#@````=````'P!`*WB`````_____```````````````*````!T````?
M`$`KF(`!``#____\```````````````@````'0```!\`0"P0@`<``/____P`
M`````````````#`````=````'P!`+)"`#P``_____``````````````0,```
M`!T````?`$`MX(````#____\```````````````@````'0```!\`0"Z(@`$`
M`/____P``````````````"`````=````'P!`,PS`_P``_____```````````
M````Z````!T````?`$`U@(`!``#____\```````````````@````'0```!\`
M0#;D@`<``/____P`````````````(#`````=````'P!`-\``````````````
M`````````````````!T````?`$`WR(!_``#____\``````````````!`````
M'0```!\`0#JLP/\``/____P``````````````&`````=````'P!`/("`#P``
M_____```````````````6````!T````?`$`^9(````#____\````````````
M```@````'0```!\`0#Z\@`,``/____P``````````````"@````=````'P!`
M0(B``P``_____```````````````*````!T````?`$!!:(`'``#____\````
M```````````P````'0```!\`0$50P/\``/____P`````````````$%`````=
M````'P!`2#3`_P``_____`````````````"!Z````!T````?`$!5)(!_``#_
M___\``````````````!`````'0```!\`0%QD@````/____P`````````````
M`"`````=````'P!`7,R`````_____```````````````*````!T````?`$!=
M@```````````````````````````````'0```!\`0%W`````````````````
M```````````````=````'P!`7<B`/P``_____```````````````.````!T`
M```?1T-#.B`H1&5B:6%N(#0N-"XU+3@I(#0N-"XU`$=#0SH@*$1E8FEA;B`T
M+C0N-2TQ,"D@-"XT+C4`00````]G;G4``0````<$`0`N<VAS=')T86(`+FEN
M=&5R<``N;F]T92Y!0DDM=&%G`"YR96=I;F9O`"YN;W1E+F=N=2YB=6EL9"UI
M9``N9'EN86UI8P`N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N
M`"YG;G4N=F5R<VEO;E]R`"YI;FET`"YT97AT`"Y-25!3+G-T=6)S`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9&%T82YR
M96PN<F\`+F1A=&$`+G)L9%]M87``+F=O=``N<V1A=&$`+F)S<P`N<&1R`"YC
M;VUM96YT`"YG;G4N871T<FEB=71E<P`N;61E8G5G+F%B:3,R````````````
M```````````````````````````````````````````````````+`````0``
M``(`0`%4```!5`````T```````````````$`````````$P````<````"`$`!
M9````60````@```````````````$`````````"%P```&`````@!``80```&$
M````&```````````````!````!@````J````!P````(`0`&<```!G````"0`
M``````````````0`````````/0````8````"`$`!P````<````$`````"```
M```````$````"````$8````%`````@!``L````+````#?`````<`````````
M!`````0```!,````"P````(`0`8\```&/```!\`````(`````0````0````0
M````5`````,````"`$`-_```#?P```9*```````````````!`````````%QO
M____`````@!`%$8``!1&````^`````<``````````@````(```!I;____@``
M``(`0!5````50````(`````(`````@````0`````````>`````$````&`$`5
MP```%<````"0```````````````$`````````'X````!````!@!`%E```!90
M``!(D```````````````$`````````"$`````0````8`0%[@``!>X```!,``
M``````````````0`````````D`````$````&`$!CH```8Z````!,````````
M```````$`````````)8````!`````@!`8_```&/P``!?X```````````````
M$`````````">`````0````(`0,/0``##T`````0```````````````0`````
M````J`````$````#`$'#U```P]0````(```````````````$`````````*\`
M```!`````P!!P]P``,/<````"```````````````!`````````"V`````0``
M``,`0</D``##Y`````0```````````````0`````````NP````$````#`$'#
MZ```P^@````(```````````````$`````````,@````!`````P!!P_```,/P
M````0```````````````$`````````#.`````0````,`0<0P``#$,`````0`
M``````````````0`````````UP````$0```#`$'$0```Q$````&$````````
M```````0````!````-P````!$````P!!Q<0``,7$````!```````````````
M!`````````#C````"`````,`0<70``#%R```$#```````````````!``````
M````Z`````$`````````````Q<@```.````````````````$`````````.T`
M```!````,````````,E(````.0```````````````0````$```#V;___]0``
M``````````#)@0```!````````````````$````````!!@````$`````````
MD```R9$````````````````````!``````````$````#`````````````,F1
4```!%````````````````0``````
